@@ -35,7 +35,9 @@ class TQTimer;
 class TDEInstance;
 class Interface;
 class BackendBase;
-class KNotifyClient::Instance;
+namespace KNotifyClient {
+    class Instance;
+}
 
 /**
  * This class is the main entry point of KNemo. It reads the configuration,
